- remove the DNS record for the subdomain
- regularly check your inventory and make sure the subdomain is still in use, and you still in control of everything your subdomains point to.
- choose your service provider wisely, and make sure they provide enough security measures to protect your subdomains.